Karl, A.T., Broatch, J. (2014). mvglmmRank: An R Package Providing Multivariate Generalized Linear Mixed Models for Evaluating Sporting Teams. Submitted.
Karl, A.T., Yang, Y. and Lohr, S. (2013). Efficient Maximum Likelihood Estimation of Multiple Membership Linear Mixed Models, with an Application to
Educational Value-Added Assessments. Computational Statistics and Data Analysis, 59, 13-27.
Karl, A., Yang, Y. and Lohr, S. (2014) Computation of Maximum Likelihood Estimates for Multiresponse Generalized Linear Mixed Models with Non-nested, Correlated Random Effects Computational Statistics & Data Analysis 73, 146--162.
Karl, A.T. (2012). The Sensitivity of College Football Rankings to Several Modeling Choices, Journal of Quantitative Analysis in Sports,
Volume 8, Issue 3, DOI 10.1515/1559-0410.1471