| mvglmmRank | R Documentation |
Fits one of several generalized linear mixed models for team scores, win/loss indicators, or margin of victory. The fitted random effects are used as team ratings.
mvglmmRank(
game.data,
method = "PB0",
first.order = FALSE,
home.field = TRUE,
max.iter.EM = 1000,
tol1 = 1e-04,
tol2 = 1e-04,
tolFE = 0,
tol.n = 1e-07,
verbose = TRUE,
OT.flag = FALSE,
Hessian = FALSE,
REML.N = TRUE
)
game.data |
A data frame with columns |
method |
Character string naming the model to fit. Choices are
|
first.order |
Logical. If |
home.field |
Logical. If |
max.iter.EM |
Maximum number of EM iterations. |
tol1 |
Convergence tolerance for the first-order Laplace approximation, based on the maximum relative parameter change. |
tol2 |
Convergence tolerance for the fully exponential Laplace
approximation. Not used when |
tolFE |
Intermediate convergence tolerance for the fully exponential approximation. Corrections to the random-effects covariance matrix begin after this tolerance is reached. |
tol.n |
Convergence tolerance for the normal models. Convergence is
declared when |
verbose |
Logical. If |
OT.flag |
Logical. If |
Hessian |
Logical. If |
REML.N |
Logical. If |
The available methods are:
"B"Binary/probit model for home win/loss indicators.
"P0"Poisson score model without a game-level random effect.
"P1"Poisson score model with a game-level random effect.
"N"Normal score model with an unstructured within-game error covariance matrix.
"NB"Joint normal score and binary/probit win/loss model.
"PB0"Joint Poisson score and binary/probit win/loss model without a game-level random effect.
"PB1"Joint Poisson score and binary/probit win/loss model with a game-level random effect.
"NB.mov"Joint normal margin-of-victory and binary/probit win/loss model.
"N.mov"Normal margin-of-victory model.
Neutral-site games are represented in game.data$neutral.site. Use
1 for neutral-site games and 0 otherwise. For neutral-site
games, the teams may be assigned to the home and away columns
arbitrarily. With home.field = TRUE, score models estimate a
neutral-site mean score when neutral-site games are present. With
home.field = FALSE, the home/away and neutral-site mean structure is
suppressed.
Setting first.order = TRUE yields the first-order Laplace
approximation. A partial fully exponential Laplace approximation can be
obtained by setting tol1 > tol2 and tolFE = 0. This applies
fully exponential corrections to the vector of team ratings, but not to the
covariance matrix of this vector. Karl, Yang, and Lohr (2014) show that this
approach produces a large portion of the benefit of the fully exponential
Laplace approximation in only a fraction of the time.
The "PB1" method is the least scalable, as its memory and
computational requirements are at least quadratic in the number of teams
plus the number of games.
An object of class "mvglmmRank". The object is a list whose
components depend on method and may include:
n.ratings.offense, n.ratings.defenseNormal-model
offensive and defensive ratings, or NULL.
p.ratings.offense, p.ratings.defensePoisson-model
offensive and defensive ratings, or NULL.
b.ratingsBinary/probit win-propensity ratings, or
NULL.
n.ratings.movNormal margin-of-victory ratings, or
NULL.
n.mean, p.mean, b.meanEstimated fixed-effect means or home-field effects for the fitted model components.
G, G.corRandom-effects covariance and correlation matrices.
R, R.corNormal-model error covariance and
correlation matrices, or NULL.
home.fieldLogical indicating whether a home-field effect was modeled.
HessianNumerical Hessian if requested, otherwise
NULL.
parametersVector of fitted model parameters.
actual, pred, sresidObserved values, fitted values, and scaled residuals where available.
N.outputAdditional normal-model matrices and covariance
output for method = "N" and method = "N.mov".
fixed.effect.model.outputAdditional fixed-effect
margin-of-victory output for method = "N.mov".
methodThe model method supplied by the user.
Broatch, J.E. and Karl, A.T. (2018). Multivariate Generalized Linear Mixed Models for Joint Estimation of Sporting Outcomes. Italian Journal of Applied Statistics, 30(2), 189-211. Also available from https://arxiv.org/abs/1710.05284.
Karl, A.T. and Zimmerman, D.L. (2021). A Diagnostic for Bias in Linear Mixed Model Estimators Induced by Dependence Between the Random Effects and the Corresponding Model Matrix. Journal of Statistical Planning and Inference, 211, 107-118. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.jspi.2020.06.004")}.
Karl, A.T., Yang, Y. and Lohr, S. (2013). Efficient Maximum Likelihood Estimation of Multiple Membership Linear Mixed Models, with an Application to Educational Value-Added Assessments. Computational Statistics and Data Analysis, 59, 13-27.
Karl, A.T., Yang, Y. and Lohr, S. (2014). Computation of Maximum Likelihood Estimates for Multiresponse Generalized Linear Mixed Models with Non-nested, Correlated Random Effects. Computational Statistics & Data Analysis, 73, 146-162. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.csda.2013.11.019")}.
Karl, A.T. (2012). The Sensitivity of College Football Rankings to Several Modeling Choices. Journal of Quantitative Analysis in Sports, 8(3). \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1515/1559-0410.1471")}.
game.pred
data(nfl2012)
fit <- mvglmmRank(nfl2012, method = "PB0", first.order = TRUE,
max.iter.EM = 1, verbose = FALSE)
game.pred(fit, home = "Denver Broncos", away = "Green Bay Packers")
result <- mvglmmRank(nfl2012, method = "PB0", first.order = TRUE,
verbose = FALSE)
print(result)
game.pred(result, home = "Denver Broncos", away = "Green Bay Packers")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.